@@ -2,7 +2,7 @@
 
 BEGIN;
 
-CREATE INDEX device_port_power_idx_ip_port on device_port_power (ip, port);
+ALTER TABLE admin ADD PRIMARY KEY (job);
 
 COMMIT;
 
